@@ -1,13 +1,13 @@
 """Provides the code to load PRAW's configuration file `praw.ini`."""
 from threading import Lock
+import configparser
 import os
 import sys
 
-from .compat import configparser
 from .exceptions import ClientException
 
 
-class _NotSet(object):
+class _NotSet:
     def __bool__(self):
         return False
 
@@ -17,7 +17,7 @@ class _NotSet(object):
         return "NotSet"
 
 
-class Config(object):
+class Config:
     """A class containing the configuration for a reddit site."""
 
     CONFIG = None
