@@ -40,7 +40,8 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     ``parent_id``           The ID of the parent comment. If it is a top-level
                             comment, this returns the submission ID instead
                             (prefixed with 't3').
-    ``permalink``           A permalink for the comment.
+    ``permalink``           A permalink for the comment. Comment objects from
+                            the inbox have a ``context`` attribute instead.
     ``replies``             Provides an instance of :class:`.CommentForest`.
     ``score``               The number of upvotes for the comment.
     ``stickied``            Whether or not the comment is stickied.
@@ -142,10 +143,11 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
             raise TypeError(
                 "Exactly one of `id`, `url`, or `_data` must be provided."
             )
-        self._replies = self._submission = None
+        self._replies = []
+        self._submission = None
         super(Comment, self).__init__(reddit, _data=_data)
         if id:
-            self.id = id  # pylint: disable=invalid-name
+            self.id = id
         elif url:
             self.id = self.id_from_url(url)
         else:
@@ -207,7 +209,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         ``reddit.inbox.comment_replies``, then the returned parent may be a
         lazy instance of either :class:`.Comment`, or :class:`.Submission`.
 
-        Lazy Comment Example:
+        Lazy comment example:
 
         .. code:: python
 
