@@ -8,7 +8,7 @@ from .mixins import FullnameMixin
 from .redditor import Redditor
 
 
-class LiveContributorRelationship(object):
+class LiveContributorRelationship:
     """Provide methods to interact with live threads' contributors."""
 
     @staticmethod
@@ -346,7 +346,7 @@ class LiveThread(RedditBase):
             raise TypeError("Either `id` or `_data` must be provided.")
         super(LiveThread, self).__init__(reddit, _data=_data)
         if id:
-            self.id = id  # pylint: disable=invalid-name
+            self.id = id
 
     def _fetch_info(self):
         return ("liveabout", {"id": self.id}, None)
@@ -425,7 +425,7 @@ class LiveThread(RedditBase):
             yield update
 
 
-class LiveThreadContribution(object):
+class LiveThreadContribution:
     """Provides a set of contribution functions to a LiveThread."""
 
     def __init__(self, thread):
@@ -617,7 +617,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
         elif thread_id and update_id:
             super(LiveUpdate, self).__init__(reddit, _data=None)
             self._thread = LiveThread(self._reddit, thread_id)
-            self.id = update_id  # pylint: disable=invalid-name
+            self.id = update_id
         else:
             raise TypeError(
                 "Either `thread_id` and `update_id`, or "
@@ -639,7 +639,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
         self._fetched = True
 
 
-class LiveUpdateContribution(object):
+class LiveUpdateContribution:
     """Provides a set of contribution functions to LiveUpdate."""
 
     def __init__(self, update):
