@@ -1,5 +1,6 @@
 """Provide the Submission class."""
-from ...compat import urljoin
+from urllib.parse import urljoin
+
 from ...const import API_PATH
 from ...exceptions import ClientException
 from ...util.cache import cachedproperty
@@ -195,7 +196,7 @@ class Submission(
         self.comment_sort = "best"
 
         if id is not None:
-            self.id = id  # pylint: disable=invalid-name
+            self.id = id
         elif url is not None:
             self.id = self.id_from_url(url)
 
@@ -301,7 +302,16 @@ class Submission(
         for submissions in self._chunk(other_submissions, 50):
             self._reddit.post(API_PATH["unhide"], data={"id": submissions})
 
-    def crosspost(self, subreddit, title=None, send_replies=True):
+    def crosspost(
+        self,
+        subreddit,
+        title=None,
+        send_replies=True,
+        flair_id=None,
+        flair_text=None,
+        nsfw=False,
+        spoiler=False,
+    ):
         """Crosspost the submission to a subreddit.
 
         .. note::
@@ -311,9 +321,16 @@ class Submission(
             object to crosspost into.
         :param title: Title of the submission. Will use this submission's
             title if `None` (default: None).
+        :param flair_id: The flair template to select (default: None).
+        :param flair_text: If the template's ``flair_text_editable`` value is
+            True, this value will set a custom text (default: None).
         :param send_replies: When True, messages will be sent to the
             submission author when comments are made to the submission
             (default: True).
+        :param nsfw: Whether or not the submission should be marked NSFW
+            (default: False).
+        :param spoiler: Whether or not the submission should be marked as
+            a spoiler (default: False).
         :returns: A :class:`~.Submission` object for the newly created
             submission.
 
@@ -337,11 +354,17 @@ class Submission(
             "sendreplies": bool(send_replies),
             "kind": "crosspost",
             "crosspost_fullname": self.fullname,
+            "nsfw": bool(nsfw),
+            "spoiler": bool(spoiler),
         }
+        for key, value in (("flair_id", flair_id), ("flair_text", flair_text)):
+            if value is not None:
+                data[key] = value
+
         return self._reddit.post(API_PATH["submit"], data=data)
 
 
-class SubmissionFlair(object):
+class SubmissionFlair:
     """Provide a set of functions pertaining to Submission flair."""
 
     def __init__(self, submission):
@@ -357,7 +380,7 @@ class SubmissionFlair(object):
 
         Choices are required in order to use :meth:`.select`.
 
-        Example:
+        For example:
 
         .. code:: python
 
@@ -551,7 +574,7 @@ class SubmissionModeration(ThingModerationMixin):
         This submission will replace an existing stickied submission if one
         exists.
 
-        Example:
+        For example:
 
         .. code:: python
 
@@ -584,7 +607,7 @@ class SubmissionModeration(ThingModerationMixin):
         This method can be used both by the submission author and moderators of
         the subreddit that the submission belongs to.
 
-        Example:
+        For example:
 
         .. code:: python
 
