@@ -325,7 +325,7 @@ class SubredditWidgets(PRAWBase):
         self._fetched = True
 
 
-class SubredditWidgetsModeration(object):
+class SubredditWidgetsModeration:
     """Class for moderating a subreddit's widgets.
 
     Get an instance of this class from :attr:`.SubredditWidgets.mod`.
@@ -351,7 +351,9 @@ class SubredditWidgetsModeration(object):
 
     def _create_widget(self, payload):
         path = API_PATH["widget_create"].format(subreddit=self._subreddit)
-        widget = self._reddit.post(path, data={"json": dumps(payload)})
+        widget = self._reddit.post(
+            path, data={"json": dumps(payload, cls=WidgetEncoder)}
+        )
         widget.subreddit = self._subreddit
         return widget
 
@@ -508,7 +510,8 @@ class SubredditWidgetsModeration(object):
                                    then find the "Calendar ID."
         :param requires_sync: A ``bool``.
         :param configuration: A ``dict`` as specified in `Reddit docs`_.
-                              Example:
+
+                              For example:
 
                               .. code-block:: python
 
@@ -553,7 +556,9 @@ class SubredditWidgetsModeration(object):
         calendar.update(other_settings)
         return self._create_widget(calendar)
 
-    def add_community_list(self, short_name, data, styles, **other_settings):
+    def add_community_list(
+        self, short_name, data, styles, description="", **other_settings
+    ):
         """Add and return a :class:`.CommunityList` widget.
 
         :param short_name: A name for the widget, no longer than 30 characters.
@@ -566,6 +571,7 @@ class SubredditWidgetsModeration(object):
                        ``headerColor``, and values of hex colors. For example,
                        ``{'backgroundColor': '#FFFF66', 'headerColor':
                        '#3333EE'}``.
+        :param description: A ``str`` containing Markdown (default: ``''``).
 
         Example usage:
 
@@ -576,14 +582,16 @@ class SubredditWidgetsModeration(object):
            subreddits = ['learnpython', reddit.subreddit('redditdev')]
            new_widget = widget_moderation.add_community_list('My fav subs',
                                                              subreddits,
-                                                             styles)
+                                                             styles,
+                                                             'description')
 
         """
         community_list = {
-            "data": [str(datum) for datum in data],
+            "data": data,
             "kind": "community-list",
             "shortName": short_name,
             "styles": styles,
+            "description": description,
         }
         community_list.update(other_settings)
         return self._create_widget(community_list)
@@ -615,7 +623,8 @@ class SubredditWidgetsModeration(object):
             key ``'url'`` which maps to the URL of an image hosted on
             Reddit's servers. Images should be uploaded using
             :meth:`.upload_image`.
-            Example:
+
+            For example:
 
             .. code-block:: python
 
@@ -671,7 +680,8 @@ class SubredditWidgetsModeration(object):
             Each ``dict`` has the key ``'url'`` which maps to the URL
             of an image hosted on Reddit's servers. Images should
             be uploaded using :meth:`.upload_image`.
-            Example:
+
+            For example:
 
             .. code-block:: python
 
@@ -1137,7 +1147,8 @@ class CommunityList(Widget, BaseList):
        styles = {'backgroundColor': '#FFFF66', 'headerColor': '#3333EE'}
        subreddits = ['learnpython', reddit.subreddit('announcements')]
        community_list = widgets.mod.add_community_list('Related subreddits',
-                                                       subreddits, styles)
+                                                       subreddits, styles,
+                                                       'description')
 
     For more information on creation, see :meth:`.add_community_list`.
 
@@ -1711,7 +1722,9 @@ class WidgetEncoder(JSONEncoder):
 
     def default(self, o):  # pylint: disable=E0202
         """Serialize ``PRAWBase`` objects."""
-        if isinstance(o, PRAWBase):
+        if isinstance(o, self._subreddit_class):
+            return str(o)
+        elif isinstance(o, PRAWBase):
             return {
                 key: val
                 for key, val in vars(o).items()
@@ -1720,7 +1733,7 @@ class WidgetEncoder(JSONEncoder):
         return JSONEncoder.default(self, o)
 
 
-class WidgetModeration(object):
+class WidgetModeration:
     """Class for moderating a particular widget.
 
     Example usage:
