@@ -1,7 +1,7 @@
 """Caching utilities."""
 
 
-class cachedproperty(object):
+class cachedproperty:
     """A decorator for caching a property's result.
 
     Similar to `property`, but the wrapped method's result is cached
@@ -15,7 +15,7 @@ class cachedproperty(object):
     The cache can be invalidated via `delattr()`, or by modifying `__dict__`
     directly. It will be repopulated on next access.
 
-    *New in version 6.3.0.*
+    .. versionadded:: 6.3.0
     """
 
     def __init__(self, func, doc=None):
